=========
Connector
=========

A connector describes the relative motions between two points. A connector also describes the behavior associated with the relative motion.


Create connectors
-----------------

CDCTerm
~~~~~~~

.. autoclass:: abaqus.Connector.CDCTerm.CDCTerm
    :noindex:

    .. autoclasstoc::

    .. automethod:: __init__


ConnectorDamage
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorDamage.ConnectorDamage
    :noindex:

    .. autoclasstoc::

ConnectorDamping
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorDamping.ConnectorDamping
    :noindex:

    .. autoclasstoc::

ConnectorElasticity
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorElasticity.ConnectorElasticity
    :noindex:

    .. autoclasstoc::

ConnectorFailure
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorFailure.ConnectorFailure
    :noindex:

    .. autoclasstoc::

ConnectorFriction
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorFriction.ConnectorFriction
    :noindex:

    .. autoclasstoc::

ConnectorLock
~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorLock.ConnectorLock
    :noindex:

    .. autoclasstoc::

ConnectorPlasticity
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorPlasticity.ConnectorPlasticity
    :noindex:

    .. autoclasstoc::

ConnectorPotential
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorPotential.ConnectorPotential
    :noindex:

    .. autoclasstoc::

ConnectorStop
~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorStop.ConnectorStop
    :noindex:

    .. autoclasstoc::

DerivedComponent
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.DerivedComponent.DerivedComponent
    :noindex:

    .. autoclasstoc::

TangentialBehavior
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.TangentialBehavior.TangentialBehavior
    :noindex:

    .. autoclasstoc::


Object features
---------------

CDCTerm
~~~~~~~

.. autoclass:: abaqus.Connector.CDCTerm.CDCTerm
    :noindex:

    .. autoclasstoc::

CDCTermArray
~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.CDCTermArray.CDCTermArray
    :noindex:

    .. autoclasstoc::

ConnectorBehaviorOption
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorBehaviorOption.ConnectorBehaviorOption
    :noindex:

    .. autoclasstoc::

ConnectorBehaviorOptionArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorBehaviorOptionArray.ConnectorBehaviorOptionArray
    :noindex:

    .. autoclasstoc::

ConnectorDamage
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorDamage.ConnectorDamage
    :noindex:

    .. autoclasstoc::

ConnectorDamping
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorDamping.ConnectorDamping
    :noindex:

    .. autoclasstoc::

ConnectorElasticity
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorElasticity.ConnectorElasticity
    :noindex:

    .. autoclasstoc::

ConnectorFailure
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorFailure.ConnectorFailure
    :noindex:

    .. autoclasstoc::

ConnectorFriction
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorFriction.ConnectorFriction
    :noindex:

    .. autoclasstoc::

ConnectorLock
~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorLock.ConnectorLock
    :noindex:

    .. autoclasstoc::

ConnectorOptions
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorOptions.ConnectorOptions
    :noindex:

    .. autoclasstoc::

ConnectorPlasticity
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorPlasticity.ConnectorPlasticity
    :noindex:

    .. autoclasstoc::

ConnectorPotential
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorPotential.ConnectorPotential
    :noindex:

    .. autoclasstoc::

ConnectorPotentialArray
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorPotentialArray.ConnectorPotentialArray
    :noindex:

    .. autoclasstoc::

ConnectorStop
~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.ConnectorStop.ConnectorStop
    :noindex:

    .. autoclasstoc::

DerivedComponent
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.DerivedComponent.DerivedComponent
    :noindex:

    .. autoclasstoc::

TangentialBehavior
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Connector.TangentialBehavior.TangentialBehavior
    :noindex:

    .. autoclasstoc::